Sensewear_report(data)Year The calendar year of recorded eventMonth The calendar month of recorded eventDay The calendar day of recorded eventDayofweek The day of that weekTime_on_body_Hrs Total time (hours) of SenseWear on bodyTime_waking_wearing_Hrs Total waking time (hours) during wearing timeTime_on_body_percent Percent of wearing time of a daySteps Total steps of the dayTime_lying_Hrs Total lying time (hours)Time_sleeping_Hrs Total sleeping time (hours)Time_sed_Hrs Total sedentary time (hours)TEE_Kcal Total energy expenditure (Kcal)Time_waking_Sedentary_Hrs When the wearer is waking, the total sedentary time (hours)Percent_waking_sed When the wearer is waking, the percentage of sedentary time to wearing timeTime_waking_Mild_Hrs When the wearer is waking, the total mild time (hours)Percent_waking_mild When the wearer is waking, the percentage of mild time to wearing timeTime_waking_Moderate_Hrs When the wearer is waking, the total moderate time (hours)Percent_waking_moderate When the wearer is waking, the percentage of moderate time to wearing timeTime_waking_MVPA_Hrs When the wearer is waking, the total MVPA time (hours)Percent_waking_MVPA When the wearer is waking, the percentage of MVPA time to wearing timeTime_waking_Vigorous_Hrs When the wearer is waking, the total vigorous time (hours)Percent_waking_vigorous When the wearer is waking, the percentage of vigorous time to wearing timeNo_sed_breaks Number of sedentary breaks (at least one minute interruption counting as a break)Time_all_break_length_Hrs Summation of time (hours) of breaksAverage_EE_break_kcal Average energy expenditure of breaksTime_below_1_METs_Hrs Total time (hours) of MET less than 1Time_btw_1_2_METs_Hrs Total time (hours) of MET between 1 and 2Time_btw_2_3_METs_Hrs Total time (hours) of MET between 2 and 3Time_btw_3_4_METs_Hrs Total time (hours) of MET between 3 and 4Time_btw_4_5_METs_Hrs Total time (hours) of MET between 4 and 5Time_btw_5_6_METs_Hrs Total time (hours) of MET between 5 and 6Time_above_6_METS_Hrs Total time (hours) of MET over 6Steps_above_1.5_METs Summation of step count when energy expenditure is >1.5 METs with step counts not equal to 0EE_steps_above_1.5METs_kcal Summation of energy expenditure for in Kcal when energy expenditure is >1.5 METs with step counts not equal to 0Steps_above_3_METs Summation of step count when energy expenditure is >3 METs with step counts not equal to 0EE_steps_above_3METs_kcal Summation of energy expenditure for in Kcal when energy expenditure is >3 METs with step counts not equal to 0Time_100_steps_per_day_Hrs Summation of time (hours) for Steps>=100 per minutePAEE_above_1.5METs_kcal Summation of energy expenditure in Kcal when energy expenditure is >1.5 METsTime_PAEE_1.5METs_Hrs Summation of time (hours) when energy expenditure is >1.5 METsPAEE_above_3METs_kcal Summation of energy expenditure in Kcal when energy expenditure is >3 METsTime_PAEE_3METs_Hrs Summation of time (hours) energy expenditure is >3 METsNo_unBouted_10min Summation of number of MVPA bout which energy expenditure is >3 METs and length is less than 10 minutesEE_unBouted_10min_Kcal Summation of energy expenditure of bout which energy expenditure is >3 METs and length is less than 10 minutesTime_unBouted_10min_Hrs Summation of time (hours) of bout which length is less than 10 minutesNo_Bout_10min Summation of number of bout which length is more than 10 minutesEE_Bouted_10min_Kcal Summation of energy expenditure of MVPA bout which length is more than 10 minutesTime_Bouted_10min_Hrs Summation of time (hours) of MVPA bout which length is more than 10 minutesNo_Bout_20min Summation of number of MVPA bout which length is more than 20 minutesEE_Bouted_20min_Kcal Summation of number of MVPA bout which length is more than 20 minutesTime_Bouted_20min_Hrs Summation of time (hours) of MVPA bout which length is more than 20 minutesNo_Bout_30min Summation of number of MVPA bout which length is more than 30 minutesEE_Bouted_30min_Kcal Summation of energy expenditure of MVPA bout which length is more than 30 minutesTime_Bouted_30min_Hrs Summation of time (hours) of MVPA bout which length is more than 30 minutesMean_bout_duration Mean MVPA bout duration which bout length is more than 10 minutes: Time_Bouted_10min_Hrs/No_Bout_10minNo_Bouts_Extra_Long_steps The number of bouts of 'extra long' (>500 steps) walks in each dayNo_Bouts_Long_steps The number of bouts of 'long' (100-499 steps) walks in each dayNo_Bouts_Moderate_steps The number of bouts of 'moderate' (20-99 steps) walks in each dayNo_Bouts_Short_steps The number of bouts of 'short' walks (<20 steps)="" in="" each="" dayMean_cadence_extra_long Mean cadence (steps/min) in 'extra long' bouts of walkingMean_cadence_long Mean cadence (steps/min) in 'long' bouts of walkingMean_cadence_moderate Mean cadence (steps/min) in 'moderate' bouts of walkingMean_cadence_short Mean cadence (steps/min) in 'short' bouts of walkingMean_cadence_day Mean cadence (steps/min) in each day
20>